CoreUI Free Bootstrap Admin Template
Author: Łukasz Holeczek
Description: CoreUI - Open Source Bootstrap Admin Template

CoreUI Icons
Github
account-logout
action-redo
action-undo
align-center
align-left
align-right
arrow-bottom
arrow-left
arrow-right
arrow-top
ban
basket-loaded
bell
bold
bookmark
briefcase
british-pound
brush
calculator
calendar
cart
chart
check
chevron-bottom
chevron-left
chevron-right
chevron-top
circle-check
circle-x
cloud
cloud-download
cloud-upload
code
cog
comment-square
credit-card
cursor
dashboard
delete
dollar
drop
envelope-closed
envelope-letter
envelope-open
euro
file
globe
graph
home
inbox
info
italic
justify-center
justify-left
justify-right
laptop
layers
lightbulb
list
location-pin
lock-locked
lock-unlocked
magnifying-glass
map
monitor
moon
note
options
paperclip
pencil
people
phone
pie-chart
print
puzzle
rss
screen-desktop
screen-smartphone
settings
share
shield
sort-ascending
sort-descending
speech
speedometer
star
sun
tablet
tags
task
thumb-down
thumb-up
trash
underline
user
user-female
user-follow
user-unfollow
wrench
yen